==> koffice-2.1.0.tar.bz2: koffice-2.1.0/krita/image/tests/kis_selected_transaction_test.cpp <==
/*
 *  Copyright (c) 2007 Boudewijn Rempt boud@valdyas.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "kis_selected_transaction_test.h"

#include <qtest_kde.h>
#include "kis_selected_transaction.h"
#include <KoColorSpace.h>
#include "kis_image.h"
#include "kis_paint_layer.h"
#include <KoColorSpaceRegistry.h>
#include "kis_paint_device.h"
#include <QUndoCommand>
#include "kis_types.h"

void KisSelectedTransactionTest::testCreation()
{

    const KoColorSpace * colorSpace = KoColorSpaceRegistry::instance()->colorSpace("RGBA", 0);
    KisImageWSP image = new KisImage(0, 512, 512, colorSpace, "layer test");
    KisNodeSP node = new KisPaintLayer(image, "bla", 0);
    QUndoCommand * cmd = new QUndoCommand();
    KisSelectedTransaction test("bla", node, cmd);

}


QTEST_KDEMAIN(KisSelectedTransactionTest, GUI)
#include "kis_selected_transaction_test.moc"

==> koffice_2.2.1.orig.tar.bz2: koffice-2.2.1/krita/image/tests/kis_selected_transaction_test.cpp <==
/*
 *  Copyright (c) 2007 Boudewijn Rempt boud@valdyas.org
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#include "kis_selected_transaction_test.h"

#include <qtest_kde.h>
#include "kis_selected_transaction.h"
#include <KoColorSpace.h>
#include "kis_image.h"
#include "kis_paint_layer.h"
#include <KoColorSpaceRegistry.h>
#include "kis_paint_device.h"
#include <QUndoCommand>
#include "kis_types.h"

void KisSelectedTransactionTest::testCreation()
{

    const KoColorSpace * colorSpace = KoColorSpaceRegistry::instance()->rgb8();
    KisImageSP image = new KisImage(0, 512, 512, colorSpace, "layer test");
    KisNodeSP node = new KisPaintLayer(image, "bla", 0);
    QUndoCommand * cmd = new QUndoCommand();
    KisSelectedTransaction test("bla", node, cmd);

}


QTEST_KDEMAIN(KisSelectedTransactionTest, GUI)
#include "kis_selected_transaction_test.moc"
